# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/5 0005
__author__ = 'huohuo'
#!/usr/bin/python

import os
import codecs
from binascii import b2a_hex
import sys
reload(sys)
sys.setdefaultencoding('utf8')


###
### pdf-miner requirements
###

from pdfminer.pdfparser import PDFParser
from pdfminer.pdfdocument import PDFDocument, PDFNoOutlines
from pdfminer.pdfpage import PDFPage
from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
from pdfminer.converter import PDFPageAggregator
from pdfminer.layout import LAParams, LTTextBox, LTTextLine, LTFigure, LTImage, LTChar
import chardet


def with_pdf(pdf_doc, fn, pdf_pwd, *args):
    """Open the pdf document, and apply the function, returning the results"""
    result = None
    try:
        # open the pdf file
        fp = open(pdf_doc, 'rb')
        # create a parser object associated with the file object
        parser = PDFParser(fp)
        # create a PDFDocument object that stores the document structure
        doc = PDFDocument(parser, pdf_pwd)
        # connect the parser and document objects
        parser.set_document(doc)
        # supply the password for initialization

        if doc.is_extractable:
            # apply the function and return the result
            result = fn(doc, *args)

        # close the pdf file
        fp.close()
    except IOError:
        # the file doesn't exist or similar problem
        pass
    return result


###
### Table of Contents
###

def _parse_toc (doc):
    """With an open PDFDocument object, get the table of contents (toc) data
    [this is a higher-order function to be passed to with_pdf()]"""
    toc = []
    try:
        outlines = doc.get_outlines()
        for (level,title,dest,a,se) in outlines:
            toc.append( (level, title) )
    except PDFNoOutlines:
        pass
    return toc


def get_toc (pdf_doc, pdf_pwd=''):
    """Return the table of contents (toc), if any, for this pdf file"""
    return with_pdf(pdf_doc, _parse_toc, pdf_pwd)


###
### Extracting Images
###

def write_file (folder, filename, filedata, flags='w'):
    """Write the file data to the folder and filename combination
    (flags: 'w' for write text, 'wb' for write binary, use 'a' instead of 'w' for append)"""
    result = False
    if os.path.isdir(folder):
        try:
            file_obj = open(os.path.join(folder, filename), flags)
            file_obj.write(filedata)
            file_obj.close()
            result = True
        except IOError:
            pass
    return result


def determine_image_type (stream_first_4_bytes):
    """Find out the image file type based on the magic number comparison of the first 4 (or 2) bytes"""
    file_type = None
    bytes_as_hex = b2a_hex(stream_first_4_bytes)
    if bytes_as_hex.startswith('ffd8'):
        file_type = '.jpeg'
    elif bytes_as_hex == '89504e47':
        file_type = '.png'
    elif bytes_as_hex == '47494638':
        file_type = '.gif'
    elif bytes_as_hex.startswith('424d'):
        file_type = '.bmp'
    return file_type


def save_image(lt_image, page_number, images_folder):
    """Try to save the image data from this LTImage object, and return the file name, if successful"""
    result = None
    if lt_image.stream:
        file_stream = lt_image.stream.get_rawdata()
        if file_stream:
            file_ext = determine_image_type(file_stream[0:4])
            if file_ext:
                file_name = ''.join([str(page_number), '_', lt_image.name, file_ext])
                if write_file(images_folder, file_name, file_stream, flags='wb'):
                    result = file_name
    return result


###
### Extracting Text
###

def to_bytestring (s, enc='utf-8'):
    """Convert the given unicode string to a bytestring, using the standard encoding,
    unless it's already a bytestring"""
    if s:
        if isinstance(s, str):
            return s
        else:
            return s.encode(enc)


def update_page_text_hash (h, lt_obj, pct=0.2):
    """Use the bbox x0,x1 values within pct% to produce lists of associated text within the hash"""

    x0 = lt_obj.bbox[0]
    x1 = lt_obj.bbox[2]

    key_found = False
    for k, v in h.items():
        hash_x0 = k[0]
        if x0 >= (hash_x0 * (1.0-pct)) and (hash_x0 * (1.0+pct)) >= x0:
            hash_x1 = k[1]
            if x1 >= (hash_x1 * (1.0-pct)) and (hash_x1 * (1.0+pct)) >= x1:
                # the text inside this LT* object was positioned at the same
                # width as a prior series of text, so it belongs together
                key_found = True
                v.append(to_bytestring(lt_obj.get_text()))
                h[k] = v
    if not key_found:
        # the text, based on width, is a new series,
        # so it gets its own series (entry in the hash)
        h[(x0,x1)] = [to_bytestring(lt_obj.get_text())]
    return h


def parse_lt_objs (lt_objs, page_number, images_folder, text=[]):
    """Iterate through the list of LT* objects and capture the text or image data contained in each"""
    text_content = []

    page_text = {} # k=(x0, x1) of the bbox, v=list of text strings within that bbox width (physical column)
    for lt_obj in lt_objs:
        if isinstance(lt_obj, LTTextBox) or isinstance(lt_obj, LTTextLine):
            # text, so arrange is logically based on its column width
            page_text = update_page_text_hash(page_text, lt_obj)
        elif isinstance(lt_obj, LTImage):
            # an image, so save it to the designated folder, and note its place in the text
            saved_file = save_image(lt_obj, page_number, images_folder)
            if saved_file:
                # use html style <img /> tag to mark the position of the image within the text
                text_content.append('<img src="'+os.path.join(images_folder, saved_file)+'" />')
            else:
                print >> sys.stderr, "error saving image on page", page_number, lt_obj.__repr__
        elif isinstance(lt_obj, LTFigure):
            # LTFigure objects are containers for other LT* objects, so recurse through the children
            text_content.append(parse_lt_objs(lt_obj, page_number, images_folder, text_content))
    # for k, v in page_text.items():
    # if page_number in [20]:
    #     print page_number, page_text.keys()
        # print page_number, ''.join(v).replace('\n', '')
    for k, v in sorted([(key,value) for (key,value) in page_text.items()]):
        # sort the page_text hash by the keys (x0,x1 values of the bbox),
        # which produces a top-down, left-to-right sequence of related columns
        text_content.append(''.join(v))
    return '\n'.join(text_content)


###
### Processing Pages
###

def _parse_pages (doc, images_folder):
    """With an open PDFDocument object, get the pages and parse each one
    [this is a higher-order function to be passed to with_pdf()]"""
    rsrcmgr = PDFResourceManager()
    laparams = LAParams()
    device = PDFPageAggregator(rsrcmgr, laparams=laparams)
    interpreter = PDFPageInterpreter(rsrcmgr, device)

    text_content = []
    for i, page in enumerate(PDFPage.create_pages(doc)):
        interpreter.process_page(page)
        # receive the LTPage object for this page
        layout = device.get_result()
        # layout is an LTPage object which may contain child objects like LTTextBox, LTFigure, LTImage, etc.
        text_content.append(parse_lt_objs(layout, (i+1), images_folder))

    return text_content


def get_pages (pdf_doc, pdf_pwd='', images_folder='/tmp'):
    """Process each of the pages in this pdf file and return a list of strings representing the text found in each page"""
    return with_pdf(pdf_doc, _parse_pages, pdf_pwd, *tuple([images_folder]))


# pdf2img(u'H:\晶云公司\\1.需求文档\下载报告\晶苗\\3.新版\晶苗报告自动化文件晶苗 总.pdf')
# folder_name=u'H:\晶云公司\\1.需求文档\下载报告\多组学临床检测报告\数据\part0'
# C_PDFNAME=u'王其君100301检测报告.pdf'
folder_name=u'H:\晶云公司\\1.需求文档\下载报告\晶苗\\3.新版\图片3'
if os.path.exists(folder_name) is False:
    os.makedirs(folder_name)
pdf_path= u'H:\晶云公司\\1.需求文档\下载报告\晶苗\\3.新版\晶苗报告自动化文件\晶苗 总.pdf'
C_JPGNAME=u'img\王其君100301检测报告%s.jpg'
text_url = os.path.join(folder_name, 'test.txt')
import codecs
if os.path.exists(text_url):
    os.remove(text_url)
a = codecs.open(text_url, 'a', 'utf-8')
pages = get_pages(pdf_path, images_folder=folder_name)
for i in pages:
    # a.write(codecs.BOM_UTF8)
    # print i
    i = i.strip('\n').strip('\t').strip()
    if i != '':
        text = i
        if isinstance(i, str):
            encoding = chardet.detect(i)['encoding']
            print encoding, type(encoding)
            if encoding != 'utf-8':
                try:
                    text = i.decode(encoding).encode('utf-8')
                except:
                    text = ''
            else:
                text = ''

        a.write(text)
a.close()

if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/6/28 0028
__author__ = 'huohuo'
import os
try:
    import PythonMagick
    from PythonMagick import Image
    import PyPDF2
except:
    pass
bgcolor = '#FFFFFF'


def pdf2img(input_pdf, postfix='.png', **kwargs):
    img = Image(input_pdf)
    img.density('300')
    size = "%sx%s" % (img.columns(), img.rows())
    output_img = Image(size, bgcolor)
    output_img.type = img.type
    output_img.composite(img, 0, 0, PythonMagick.CompositeOperator.SrcOverCompositeOp)
    output_img.resize(str(img.rows()))
    output_img.magick('JPG')
    output_img.quality(75)
    if 'out_path' in kwargs:
        output_jpg = kwargs['out_path']
    else:
        output_jpg = input_pdf.replace(".pdf", postfix)
    if os.path.exists(output_jpg):
        os.remove(output_jpg)
    output_img.write(output_jpg)



class ManImage:
    """
    Manipulate Image Object
    """
    def __init__(self, i_file, o_dire):
        """
        init args
        :param i_file: (str) input pdf file (eg: "/home/file.pdf")
        :param o_dire: (str) output image directory (eg: "/home/")
        """
        self.i_file = i_file
        self.o_dire = o_dire

    def __str__(self):
        traceback = "Executing under {0.argv[0]} of {1.i_file} into {2.o_dire}......".format(sys, self, self)
        return traceback

    def playpdf(self, ds):
        """
        split pdf file
        :param ds: (int) set ds = 1024 ~= 1MB output under my test
        :return: splited PNG image file
        """
        # PythonMagick.Image
        pdf_file = PyPDF2.PdfFileReader(file(self.i_file, "rb"))
        pages = pdf_file.getNumPages()
        print('Totally get ***{0:^4}*** pages from "{1.i_file}", playpdf start......'.format(pages, self))
        try:
            for i in range(pages):
                image = PythonMagick.Image(self.i_file + '[' + str(i) + ']')
                # image.density(str(ds))
                image.read(self.i_file + '[' + str(i) + ']')
                image.magick("PNG")
                image.write(os.path.join(self.o_dire, '%d.png'%(i+1)))
                print("{0:>5}     page OK......".format(i + 1))
        except Exception, e:
            print(str(e))



if __name__ == "__main__":
    # pdf2img('D:\pythonproject\\report\data\part1\\tmb.pdf')
    pdf_path = r'/pythonproject/GATCReport/results/report2.pdf'
    dir_name = r'D:\pythonproject\GATCWeb_04\Web3\static'
    o_dire = os.path.join(dir_name, 'report2')
    if os.path.exists(o_dire) is False:
        os.makedirs(o_dire)
    ManImage(i_file=pdf_path, o_dire=o_dire).playpdf(ds=1024)
    # pdf2png(pdf_path, o_dire)




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/6/12 0012
__author__ = 'huohuo'
mounts = 130000-12000
year = 12
month = year * 12
day = year * 365
pay = 2500


# first month
print u'总金额%s' % mounts
zaijies = [0, 9833.33+1416-2500]
for m in range(1, month):
    # m = 1
    y = m / 12 + 1
    m1 = m % 12
    mounts += zaijies[m]
    benjin = mounts / 12.0
    lixi = mounts * 0.04 * 0.01 * m * 30
    zaijies.append(max(benjin + lixi - pay, 0))

    mounts = mounts - lixi + pay
    print u'第%s年，第%s个月，本金%.2f，利息%.2f, 再借%.2f, 总债务%.2f' % (y, m1, benjin, lixi, zaijies[m], mounts)
    if mounts <= 0:
        break


# for i in range(month):
#     lixi = mounts * 0.04 * 0.01 * i * 30
#     # 30 day
#     print lixi
#     mounts = mounts + lixi - pay
#     if mounts <= 0:
#         break
#     print i, lixi, mounts


if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/8/20 0020
__author__ = 'huohuo'
import json
from jy_word.File import File

import matplotlib.pyplot as plt

linjian = 'L0002_lingjian'
my_file = File()
data = my_file.read('%s.csv' % linjian)
for k in data[0].keys():
    print k
n = 0
plt.figure(figsize=(50, 500))
color = ['r', 'g', 'y', 'b']
for index, item in enumerate(data):
    dots = json.loads(item['外轮廓'])
    c_index = index % len(color)
    c = color[c_index]
    dotx, doty = [], []
    for dot in dots:
        dotx.append(dot[0])
        doty.append(dot[1])
    plt.plot(dotx, doty, '-', color=c)
    print item['零件号'], len(dots)

    plt.text(float(dot[0]), float(dot[1]), str(index))
    n += len(dots)
plt.xlabel('x')
plt.ylabel('y')
plt.title(linjian)
# plt.show()
plt.savefig('%s.png' % linjian, dpi=100)
print len(data), n
plt.show()

if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/10 0010
__author__ = 'huohuo'

import time
import multiprocessing


def write_file(filename,num):
    target = open(filename, 'w')
    for i in range(1,num+1):
        target.write("%d line\n" % i)

if __name__ == '__main__':
    # start = time.time()
    #
    # p1 = multiprocessing.Process(target=write_file,args=('1.txt', 1000000))
    # p2 = multiprocessing.Process(target=write_file,args=('2.txt', 2000000))
    #
    # #启动子进程
    # p1.start()
    # p2.start()
    #
    # #等待fork的子进程终止再继续往下执行，可选填一个timeout参数
    # p1.join()
    # p2.join()
    #
    # end = time.time()
    # print str(round(end-start,3))+'s'

    start = time.time()
    #100W
    write_file('1.txt', 1000000)
    #200W
    write_file('2.txt', 2000000)

    end = time.time()
    print str(round(end-start,3))+'s'



# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/1/29 0029
__author__ = 'huohuo'

# from django.http import JsonResponse
import requests
from alipay import AliPay
import json
import os
import time,qrcode
import sys
reload(sys)
sys.setdefaultencoding('utf-8')
#注意：一个是支付宝公钥，一个是应用私钥


def pay(order_id, total_amount, subject):
    # order_id = request.POST.get("order_id")
    # 创建用于进行支付宝支付的工具对象
    alipay = init_alipay()

    # 电脑网站支付，api_alipay_trade_page_pay 需要跳转到https://openapi.alipay.com/gateway.do? + order_string
    # APP支付， api_alipay_trade_wap_pay
    order_string = alipay.api_alipay_trade_page_pay(
        out_trade_no=order_id,
        total_amount=str(total_amount),  # 将Decimal类型转换为字符串交给支付宝
        subject=subject,
        return_url='https://www.gene.ac/event/success/',
        notify_url=None  # 可选, 不填则使用默认notify url
    )
    # 让用户进行支付的支付宝页面网址
    url = ALIPAY_URL + "?" + order_string
    print url
    return {"code": 0, "message": "请求支付成功", "url": url}


def check_pay(out_trade_no):
    # 创建用于进行支付宝支付的工具对象
    alipay = init_alipay()
    biz_content = {}
    if out_trade_no:
        biz_content["out_trade_no"] = out_trade_no
    data = alipay.build_body("alipay.trade.query", biz_content)
    url = alipay._gateway + "?" + alipay.sign_data(data)
    raw_string = requests.request('GET', url, timeout=15, headers={'Content-Type': 'application/json'})
    res = raw_string.json()
    return res.get('alipay_trade_query_response')


def init_alipay():
    # 创建用于进行支付宝支付的工具对象
    alipay = AliPay(
        appid=ALIPAY_APPID,
        app_notify_url=None,  # 默认回调url
        app_private_key_string=app_private_key_string,
        alipay_public_key_string=alipay_public_key_string,
        # 支付宝的公钥，验证支付宝回传消息使用，不是你自己的公钥,
        sign_type="RSA2",  # RSA2,官方推荐，配置公钥的时候能看到
        debug=False  # 默认False  配合沙箱模式使用
    )
    return alipay


def get_qr_code(code_url):
    '''
    生成二维码
    :return None
    '''
    #print(code_url)
    qr = qrcode.QRCode(
        version=1,
        error_correction=qrcode.constants.ERROR_CORRECT_H,
        box_size=10,
        border=1
    )
    qr.add_data(code_url)  # 二维码所含信息
    img = qr.make_image()  # 生成二维码图片
    img.save(r'qr_test_ali.png')
    print('二维码保存成功！')


def preCreateOrder(subject, out_trade_no, total_amount):
    '''
    创建预付订单
    :param subject: order_desc
    :param out_trade_no:int
    :param total_amount:(float,'eg:0.01')
    :return None：表示预付订单创建失败  [或]  code_url：二维码url
    '''
    alipay = init_alipay()

    print 'subject', subject
    print 'out_trade_no', out_trade_no
    print 'total_amount', total_amount
    result = alipay.api_alipay_trade_precreate(subject=subject, out_trade_no=out_trade_no, total_amount=total_amount)
    print('返回值：', result)
    code_url = result.get('qr_code')
    if not code_url:
        print(result.get('预付订单创建失败：','msg'))
        return
    else:
        get_qr_code(code_url)
        #return code_url


def query_order(out_trade_no, cancel_time):
    '''
    :param out_trade_no: 商户订单号 int
    :param cancel_time:int and 'secs'
    :return: None
    '''
    print('预付订单已创建,请在%s秒内扫码支付,过期订单将被取消！'% cancel_time)
    # check order status
    _time = 0
    for i in range(10):
        # check every 3s, and 10 times in all

        print("now sleep 2s")
        time.sleep(2)

        result = init_alipay().api_alipay_trade_query(out_trade_no=out_trade_no)
        if result.get("trade_status", "") == "TRADE_SUCCESS":
            print('订单已支付!')
            print('订单查询返回值：',result)
            break

        _time += 2
        if _time >= cancel_time:
            cancel_order(out_trade_no,cancel_time)
            return


def cancel_order(out_trade_no, cancel_time=None):
    '''
    撤销订单
    :param out_trade_no: int
    :param cancel_time: 撤销前的等待时间(若未支付)，撤销后在商家中心-交易下的交易状态显示为"关闭"
    :return:
    '''
    alipay = init_alipay()
    print out_trade_no
    result = alipay.api_alipay_trade_cancel(out_trade_no=out_trade_no)
    #print('取消订单返回值：', result)
    resp_state = result.get('msg')
    action = result.get('action')
    if resp_state=='Success':
        if action=='close':
            if cancel_time:
                print("%s秒内未支付订单，订单已被取消！" % cancel_time)
        elif action=='refund':
            print('该笔交易目前状态为：',action)

        return action

    else:
        print('请求失败：',resp_state)
        return


def need_refund(out_trade_no, refund_amount, out_request_no):
    '''
    退款操作
    :param out_trade_no: 商户订单号 str or int
    :param refund_amount: 退款金额，小于等于订单金额 int or float
    :param out_request_no: 商户自定义参数，用来标识该次退款请求的唯一性,可使用 out_trade_no_退款金额*100 的构造方式 str
    :return:
    '''
    result = init_alipay().api_alipay_trade_refund(out_trade_no=out_trade_no,
                                                   refund_amount=refund_amount,
                                                   out_request_no=out_request_no)

    if result["code"] == "10000":
        return result  #接口调用成功则返回result
    else:
        return result["msg"] #接口调用失败则返回原因


def refund_query(out_request_no, out_trade_no):
    '''
    退款查询：同一笔交易可能有多次退款操作（每次退一部分）
    :param out_request_no: 商户自定义的单次退款请求标识符 str
    :param out_trade_no: 商户订单号 str or int
    :return:
    '''
    result = init_alipay().api_alipay_trade_fastpay_refund_query(out_request_no, out_trade_no=out_trade_no)

    if result["code"] == "10000":
        return result  #接口调用成功则返回result
    else:
        return result["msg"] #接口调用失败则返回原因


def create_order(out_trade_no, total_amount, subject):
    alipay = init_alipay()
    order_string = alipay.api_alipay_trade_app_pay(
        out_trade_no=out_trade_no,
        total_amount=total_amount,
        subject=subject,
        notify_url="https://example.com/notify" # 可选, 不填则使用默认notify url
    )
    print order_string


if __name__ == '__main__':
    # cancel_order(1527212120)
    subject = "Early-bird (by Mar. 10, 2019)"
    out_trade_no = int(time.time())
    total_amount = 0.01
    # from jy_word.web_tool import format_time
    # timestamp = format_time(out_trade_no)
    # print out_trade_no
    # result = pay(out_trade_no, total_amount, subject)
    # print result['message']
    out_trade_no = 1550651456
    out_trade_no = '20190221085620055000'
    print 'ALIPAY_APPID', ALIPAY_APPID
    result2 = check_pay(out_trade_no)
    # print result2

    # # pay_test(out_trade_no, timestamp)
    # preCreateOrder(subject, out_trade_no,total_amount)
    # #
    # query_order(out_trade_no,40)
    # #
    # # print('5s后订单自动退款')
    # # time.sleep(5)
    # print(need_refund(out_trade_no,0.01,111))
    # #
    # # print('5s后查询退款')
    # # time.sleep(5)
    # print(refund_query(out_request_no=111, out_trade_no=out_trade_no))
    # # 操作完登录 https://authsu18.alipay.com/login/index.htm中的对账中心查看是否有一笔交易生成并退款
    # create_order(out_trade_no, total_amount, subject)
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/1/29 0029
__author__ = 'huohuo'
import requests
import paypalrestsdk

client_id = 'client_id'
secret = 'secret'
grant_type = 'client_credentials'
api_hosts = 'http://fa-online.tsinghua.edu.cn/sftp/requestPayAction!payment.action'
rq_pay = {
    "intent": "sale",
    "payer": {"payment_method": "paypal"},
    "redirect_urls": {
        "return_url": "http://172.16.110.197:3303/event/success/",
        "cancel_url": "http://172.16.110.197:3303/event/#event_payment"},
    "transactions": [{
        "item_list": {
            "items": [{
                "name": "item",
                "sku": "item",
                "price": "1.50",
                "currency": "USD",
                "quantity": 1}]},
        "amount": {
            "total": "1.5",
            "currency": "USD"},
        "description": "This is the payment transaction description."}]
}


def get_access_token():
    rq = {'grant_type': grant_type}
    url = '%s/v1/oauth2/token' % api_hosts
    headers = {'Accept': 'application/json'}
    r = requests.request('post', url, headers=headers, auth=(client_id, secret), params=rq)
    if r.status_code == 200:
        res = r.json()
        return res
    else:
        print r.status_code
    return None


def pay():
    res1 = get_access_token()
    for k in res1:
        print k, res1[k]
    access_token = res1.get('access_token')
    url = '%s/v1/payments/payment' % api_hosts
    authorization = 'bearer %s' % access_token
    print authorization
    headers = {'Authorization': authorization}
    r = requests.request('post', url, headers=headers, json=rq_pay, auth=(client_id, secret))
    if r.status_code == 200:
        res = r.json()
        print res
        return res.get('access_token')
    else:
        print r.status_code, r.text


def pay_sdk():
    paypalrestsdk.configure({
        "mode": "sandbox", # sandbox or live
        "client_id": client_id, "client_secret": secret})
    payment = paypalrestsdk.Payment(rq_pay)
    # paypalrestsdk.Order()
    if payment.create():
        print 'create', payment
    else:
        print(payment.error)

def get_order_tsinghua():
    import datetime
    out_trade_no = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')
    total_fee = 0.01
    pay_type = '2'  # 1手机端支付，2 PC端支付
    alipay = 100862
    wxpay = 100863
    rq = {
        't_partner': '2025',
        't_out_trade_no': 'tcdf%s%s1234' % (alipay, out_trade_no[:-3]),
        't_business': 'tcdf2019_wk',
        't_user_id': '410881199102215029',
        't_user_id_type': '0',
        't_username': '霍佩佩',
        't_name': '测试',
        't_summary': 'ceshi',
        't_total_fee': '%0.2f' % total_fee,
        't_return_url': 'https://www.gene.ac/event/success/',
        't_pay_type': pay_type,
        't_datetime': out_trade_no[:-3]
    }



# pay()
if __name__ == "__main__":
    # pay_sdk()
    get_order_tsinghua()
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2019/3/19 0019
__author__ = 'huohuo'
"""
    Group Chat Robot v0.1
"""

import itchat, re
from itchat.content import *
import random
import json

"""
    Constants
"""
REPLY = {'工作':['且不说你的工作多么认真，我并没有见过，但是从你的字里行间，我发现了乔布斯的影子和小扎的气息，这已经不是一份工作那么简单，而是一场精神饕餮！',
               '你拥有了这个年龄段近半数人无法拥有的理想职业，太优秀了！',
               '工作这件事，大家都习以为常，只有你让大家开始思考这个问题，说明你善于反思和质疑当前的制度，你的公司会因为你这样的人变得更好！'],
         '学习':['这么多优秀的同龄人相聚在这里，一定是场思想交流的盛宴。','看到群友们的发言，真是排山倒海，气宇轩昂之势！',
               '你这句话完美的表达了你想被夸的坚定信念，你一定是一个执着追求自己理想的人！'],
         'default': ['太棒了','真不错','好开心','嗯嗯','没什么好说的了，我送你一道彩虹屁吧']}


@itchat.msg_register([TEXT], isGroupChat=False)
def text_reply(msg):
    print msg['User']
    if msg['User']['UserName'] == 'filehelper':
        print('Message from: %s' % msg['User']['UserName'])
        # 发送者的昵称
        # username = msg['ActualNickName']
        # print('Who sent it: %s' % username)

        match = re.search('工作', msg['Text']) or re.search('加班', msg['Text'])
        if match:
            print('-+-+' * 5)
            print('Message content:%s' % msg['Content'])
            print('工作、加班 is: %s' % (match is not None))
            randomIdx = random.randint(0, len(REPLY['工作']) - 1)
            itchat.send('%s\n%s' % (username, REPLY['工作'][randomIdx]), msg['FromUserName'])

        match = re.search('学习', msg['Text']) or re.search('考试', msg['Text'])
        if match:
            print('-+-+' * 5)
            print('Message content:%s' % msg['Content'])
            print('学习、考试 is: %s' % (match is not None))
            randomIdx = random.randint(0, len(REPLY['学习']) - 1)
            itchat.send('%s\n%s' % (username, REPLY['学习'][randomIdx]), msg['FromUserName'])

        print('isAt is:%s' % msg['isAt'])

        if msg['isAt']:
            randomIdx = random.randint(0, len(REPLY['default']) - 1)
            itchat.send('%s\n%s' % (username, REPLY['default'][randomIdx]), msg['FromUserName'])
            print('-+-+'*5)


if __name__ == "__main__":
    itchat.auto_login(enableCmdQR=False, hotReload=True)
    itchat.run()
    pass
    

